oaspec/capability

Types

A capability entry.

pub type Capability {
  Capability(
    name: String,
    category: String,
    level: SupportLevel,
    note: String,
  )
}

Constructors

  • Capability(
      name: String,
      category: String,
      level: SupportLevel,
      note: String,
    )

Support level for an OpenAPI feature.

pub type SupportLevel {
  Supported
  Normalizable
  ParsedNotUsed
  Unsupported
  NotHandled
}

Constructors

  • Supported

    Fully supported in parsing and code generation

  • Normalizable

    Parsed, normalized to supported form by normalize pass

  • ParsedNotUsed

    Parsed and preserved but not used by codegen (warning emitted)

  • Unsupported

    Parsed but not supported for codegen (error emitted)

  • NotHandled

    Not handled by parser

Values

pub fn by_level(level: SupportLevel) -> List(Capability)

Get capabilities by level.

pub fn generate_boundaries_markdown() -> String

Generate the “Current Boundaries” markdown section from the registry.

pub fn is_unsupported_security_type(type_name: String) -> Bool

Check if a security scheme type is unsupported.

pub fn registry() -> List(Capability)

The single source of truth for feature support.

pub fn unsupported_schema_keywords() -> List(String)

Get the list of unsupported schema keywords from the registry.

Search Document