oaspec/capability
Types
A capability entry.
pub type Capability {
Capability(
name: String,
category: String,
level: SupportLevel,
note: String,
)
}
Constructors
-
Capability( name: String, category: String, level: SupportLevel, note: String, )
Support level for an OpenAPI feature.
pub type SupportLevel {
Supported
Normalizable
ParsedNotUsed
Unsupported
NotHandled
}
Constructors
-
SupportedFully supported in parsing and code generation
-
NormalizableParsed, normalized to supported form by normalize pass
-
ParsedNotUsedParsed and preserved but not used by codegen (warning emitted)
-
UnsupportedParsed but not supported for codegen (error emitted)
-
NotHandledNot handled by parser
Values
pub fn generate_boundaries_markdown() -> String
Generate the “Current Boundaries” markdown section from the registry.
pub fn is_unsupported_security_type(type_name: String) -> Bool
Check if a security scheme type is unsupported.
pub fn unsupported_schema_keywords() -> List(String)
Get the list of unsupported schema keywords from the registry.