oaspec/codegen/import_analysis
Values
pub fn operations_have_optional_body(
operations: List(
#(
String,
spec.Operation(spec.Resolved),
String,
spec.HttpMethod,
),
),
) -> Bool
Check if any operation has an optional (non-required) request body.
pub fn operations_have_optional_params(
operations: List(
#(
String,
spec.Operation(spec.Resolved),
String,
spec.HttpMethod,
),
),
) -> Bool
Check if any operation has optional (non-required) parameters.
pub fn operations_need_typed_schemas(
operations: List(
#(
String,
spec.Operation(spec.Resolved),
String,
spec.HttpMethod,
),
),
) -> Bool
Check if any operation has parameters with Reference schemas, or request body content with Reference/ObjectSchema/AllOfSchema. This determines whether the generated module needs to import the types module.