oaspec/codegen/types
Values
pub fn collect_operations(
ctx: context.Context,
) -> List(#(String, spec.Operation, String, spec.HttpMethod))
Collect all operations from the spec with their IDs, paths, and methods.
pub fn generate(
ctx: context.Context,
) -> List(context.GeneratedFile)
Generate type definitions from OpenAPI schemas.
pub fn schema_ref_to_type(
ref: schema.SchemaRef,
ctx: context.Context,
) -> String
Convert a SchemaRef to a Gleam type string.
pub fn schema_to_gleam_type(
schema: schema.SchemaObject,
ctx: context.Context,
) -> String
Convert a schema object to a Gleam type string.